#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-6JBQH6eCl9dCpUK6ouEzzx
key:                  unagi-streams-0.2.7-6JBQH6eCl9dCpUK6ouEzzx
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  13e65703c2c71f7b176e9ad1663ad025
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-6JBQH6eCl9dCpUK6ouEzzx
depends:
    base-4.18.2.1 io-streams-1.5.2.2-DpWEoroqpDpAOLzDeva14M
    unagi-chan-0.4.1.4-AfrvfYBjXvz3gBFpSt0wz2

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

